import { declare } from '@babel/helper-plugin-utils';
import { types } from '@babel/core';

var index = declare(api => {
  api.assertVersion(7);
  function transformStatementList(paths) {
    for (const path of paths) {
      if (!path.isFunctionDeclaration()) continue;
      const func = path.node;
      const declar = types.variableDeclaration("let", [types.variableDeclarator(func.id, types.toExpression(func))]);
      declar._blockHoist = 2;
      func.id = null;
      path.replaceWith(declar);
    }
  }
  return {
    name: "transform-block-scoped-functions",
    visitor: {
      BlockStatement(path) {
        const {
          node,
          parent
        } = path;
        if (types.isFunction(parent, {
          body: node
        }) || types.isExportDeclaration(parent)) {
          return;
        }
        transformStatementList(path.get("body"));
      },
      SwitchCase(path) {
        transformStatementList(path.get("consequent"));
      }
    }
  };
});

export { index as default };
//# sourceMappingURL=index.js.map
